@@ -110,14 +110,15 @@ def pyflakes_check(data, filename):
             # Avoid using msg, since for the only known case, it contains a
             # bogus message that claims the encoding the file declared was
             # unknown.
-            return ["%s: problem decoding source" % (filename, )]
+            print >> sys.stderr, "%s: problem decoding source" % (filename, )
         else:
             line = text.splitlines()[-1]
 
             if offset is not None:
                 offset = offset - (len(text) - len(line))
 
-            return ['%s:%d: %s' % (filename, lineno, msg)]
+            print >> sys.stderr, '%s:%d: %s' % (filename, lineno, msg)
+        return 1
     else:
         # Okay, it's syntactically valid.  Now parse it into an ast and check
         # it.
